#######################################
Welcome to nuitrcs_example's documentation!
#######################################


*********************
Package documentation
*********************

Please consult these pages for more details on using nuitrcs_example:

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
